@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.33_01';
+our $VERSION = '0.35_01';
 
 use AnyEvent::RipeRedis::Error;
 
@@ -66,9 +66,10 @@ my %NEED_PREPROCESS = (
 );
 
 my %NEED_POSTPROCESS = (
-  info   => 1,
-  select => 1,
-  quit   => 1,
+  info         => 1,
+  cluster_info => 1,
+  select       => 1,
+  quit         => 1,
 );
 
 my %ERR_PREFS_MAP = (
@@ -850,9 +851,10 @@ sub _process_success {
     shift @{ $self->{_processing_queue} };
 
     if ( exists $NEED_POSTPROCESS{ $cmd->{name} } ) {
-      if ( $cmd->{name} eq 'info' ) {
-        $reply = { map { split( m/:/, $_, 2 ) }
-            grep { m/^[^#]/ } split( EOL, $reply ) };
+      if ( $cmd->{name} eq 'info'
+        || $cmd->{name} eq 'cluster_info' )
+      {
+        $reply = _parse_info($reply);
       }
       elsif ( $cmd->{name} eq 'select' ) {
         $self->{database} = $cmd->{args}[0];
@@ -868,6 +870,11 @@ sub _process_success {
   return;
 }
 
+sub _parse_info {
+  return { map { split( m/:/, $_, 2 ) }
+      grep { m/^[^#]/ } split( EOL, $_[0] ) };
+}
+
 sub _disconnect {
   my $self = shift;
   my $err  = shift;
@@ -1846,7 +1853,7 @@ Ivan Kruglov
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2012-2016, Eugene Ponizovsky, SMS Online. All rights reserved.
+Copyright (c) 2012-2017, Eugene Ponizovsky, SMS Online. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
